aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/groupposition
diff options
context:
space:
mode:
authorNathan Guse <nathaniel.guse@gmail.com>2013-09-30 18:24:46 -0500
committerNathan Guse <nathaniel.guse@gmail.com>2013-09-30 18:24:46 -0500
commita6df011a107132390ecc35b80ab0e88bc31fd103 (patch)
treec91b2a90f4c3cef95c1f734aa0b6b0da4007e2ac /phpBB/phpbb/groupposition
parent2ee22d4615a86a33d3c65f94d7a9c4b99dfb1b7e (diff)
parent179f41475b555d0a3314d779d0d7423f66f0fb95 (diff)
downloadforums-a6df011a107132390ecc35b80ab0e88bc31fd103.tar
forums-a6df011a107132390ecc35b80ab0e88bc31fd103.tar.gz
forums-a6df011a107132390ecc35b80ab0e88bc31fd103.tar.bz2
forums-a6df011a107132390ecc35b80ab0e88bc31fd103.tar.xz
forums-a6df011a107132390ecc35b80ab0e88bc31fd103.zip
Merge branch 'develop' of github.com:phpbb/phpbb3 into ticket/11850
# By Nils Adermann (68) and others # Via Andreas Fischer (12) and others * 'develop' of github.com:phpbb/phpbb3: (102 commits) [ticket/11876] Replace MD5 with SHA256. [ticket/11876] Move checksum generation from build PHP files to phing build.xml [develop-olympus] Build against 3.0.12 instead of 3.0.12-RC3. Tag exists now. [prep-release-3.0.12] Update changelog for 3.0.12 release. [ticket/11873] Add unit test for large password input. [ticket/11873] Do not hash very large passwords in order to safe resources. [ticket/11862] Correct var names in user_delete() events due to prune-users [develop-olympus] Use 3.0.13-dev as build version. Use latest 3.0.12 RC tag. [prep-release-3.0.12] Bumping version number for 3.0.12 final. [ticket/11852] Add class file [ticket/11852] Move tests to folder with new class name [ticket/11852] Split filesystem and path_helper into 2 classes [ticket/11868] Add @depends to test [ticket/11868] Add functional test for registration [ticket/11868] Replace phpbb_request_interface references [ticket/11866] Only single backslash in .md files [ticket/11866] Remove outdated and broken develop script [ticket/11866] More namespaces [ticket/11866] Update some occurances of phpbb_db_ to new Namespace [ticket/11865] Convert old class name to namespaced version ... Conflicts: tests/security/extract_current_page_test.php tests/session/testable_facade.php
Diffstat (limited to 'phpBB/phpbb/groupposition')
-rw-r--r--phpBB/phpbb/groupposition/exception.php4
-rw-r--r--phpBB/phpbb/groupposition/groupposition_interface.php (renamed from phpBB/phpbb/groupposition/interface.php)6
-rw-r--r--phpBB/phpbb/groupposition/legend.php16
-rw-r--r--phpBB/phpbb/groupposition/teampage.php26
4 files changed, 30 insertions, 22 deletions
diff --git a/phpBB/phpbb/groupposition/exception.php b/phpBB/phpbb/groupposition/exception.php
index e4ff09c703..3a8d92dbc7 100644
--- a/phpBB/phpbb/groupposition/exception.php
+++ b/phpBB/phpbb/groupposition/exception.php
@@ -7,6 +7,8 @@
*
*/
+namespace phpbb\groupposition;
+
/**
* @ignore
*/
@@ -18,6 +20,6 @@ if (!defined('IN_PHPBB'))
/**
* @package groupposition
*/
-class phpbb_groupposition_exception extends \Exception
+class exception extends \Exception
{
}
diff --git a/phpBB/phpbb/groupposition/interface.php b/phpBB/phpbb/groupposition/groupposition_interface.php
index eacc04e1a4..a568785185 100644
--- a/phpBB/phpbb/groupposition/interface.php
+++ b/phpBB/phpbb/groupposition/groupposition_interface.php
@@ -7,6 +7,8 @@
*
*/
+namespace phpbb\groupposition;
+
/**
* @ignore
*/
@@ -22,7 +24,7 @@ if (!defined('IN_PHPBB'))
*
* @package phpBB3
*/
-interface phpbb_groupposition_interface
+interface groupposition_interface
{
/**
* Returns the value for a given group, if the group exists.
@@ -32,7 +34,7 @@ interface phpbb_groupposition_interface
public function get_group_value($group_id);
/**
- * Get number of groups displayed
+ * Get number of groups displayed
*
* @return int value of the last item displayed
*/
diff --git a/phpBB/phpbb/groupposition/legend.php b/phpBB/phpbb/groupposition/legend.php
index 7fddadde99..9a1ef3d1d0 100644
--- a/phpBB/phpbb/groupposition/legend.php
+++ b/phpBB/phpbb/groupposition/legend.php
@@ -7,6 +7,8 @@
*
*/
+namespace phpbb\groupposition;
+
/**
* @ignore
*/
@@ -23,7 +25,7 @@ if (!defined('IN_PHPBB'))
*
* @package phpBB3
*/
-class phpbb_groupposition_legend implements phpbb_groupposition_interface
+class legend implements \phpbb\groupposition\groupposition_interface
{
/**
* Group is not displayed
@@ -32,23 +34,23 @@ class phpbb_groupposition_legend implements phpbb_groupposition_interface
/**
* Database object
- * @var phpbb_db_driver
+ * @var \phpbb\db\driver\driver
*/
protected $db;
/**
* User object
- * @var phpbb_user
+ * @var \phpbb\user
*/
protected $user;
/**
* Constructor
*
- * @param phpbb_db_driver $db Database object
- * @param phpbb_user $user User object
+ * @param \phpbb\db\driver\driver $db Database object
+ * @param \phpbb\user $user User object
*/
- public function __construct(phpbb_db_driver $db, phpbb_user $user)
+ public function __construct(\phpbb\db\driver\driver $db, \phpbb\user $user)
{
$this->db = $db;
$this->user = $user;
@@ -71,7 +73,7 @@ class phpbb_groupposition_legend implements phpbb_groupposition_interface
if ($current_value === false)
{
// Group not found.
- throw new phpbb_groupposition_exception('NO_GROUP');
+ throw new \phpbb\groupposition\exception('NO_GROUP');
}
return (int) $current_value;
diff --git a/phpBB/phpbb/groupposition/teampage.php b/phpBB/phpbb/groupposition/teampage.php
index 7c758199e7..4e8228eb58 100644
--- a/phpBB/phpbb/groupposition/teampage.php
+++ b/phpBB/phpbb/groupposition/teampage.php
@@ -7,6 +7,8 @@
*
*/
+namespace phpbb\groupposition;
+
/**
* @ignore
*/
@@ -22,7 +24,7 @@ if (!defined('IN_PHPBB'))
*
* @package phpBB3
*/
-class phpbb_groupposition_teampage implements phpbb_groupposition_interface
+class teampage implements \phpbb\groupposition\groupposition_interface
{
/**
* Group is not displayed
@@ -36,30 +38,30 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
/**
* Database object
- * @var phpbb_db_driver
+ * @var \phpbb\db\driver\driver
*/
protected $db;
/**
* User object
- * @var phpbb_user
+ * @var \phpbb\user
*/
protected $user;
/**
* Cache object
- * @var phpbb_cache_driver_interface
+ * @var \phpbb\cache\driver\driver_interface
*/
protected $cache;
/**
* Constructor
*
* @param phpbb_db_driver $db Database object
* @param phpbb_user $user User object
* @param phpbb_cache_driver_interface $cache Cache object
*/
- public function __construct(phpbb_db_driver $db, phpbb_user $user, phpbb_cache_driver_interface $cache)
+ public function __construct(\phpbb\db\driver\driver $db, \phpbb\user $user, \phpbb\cache\driver\driver_interface $cache)
{
$this->db = $db;
$this->user = $user;
@@ -86,7 +88,7 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
if ($row === false)
{
// Group not found.
- throw new phpbb_groupposition_exception('NO_GROUP');
+ throw new \phpbb\groupposition\exception('NO_GROUP');
}
return (int) $row['teampage_position'];
@@ -113,7 +115,7 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
if ($row === false)
{
// Group not found.
- throw new phpbb_groupposition_exception('NO_GROUP');
+ throw new \phpbb\groupposition\exception('NO_GROUP');
}
return $row;
@@ -137,7 +139,7 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
if ($current_value === false)
{
// Group not found.
- throw new phpbb_groupposition_exception('NO_GROUP');
+ throw new \phpbb\groupposition\exception('NO_GROUP');
}
return (int) $current_value;
@@ -161,7 +163,7 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
if ($row === false)
{
// Group not found.
- throw new phpbb_groupposition_exception('NO_GROUP');
+ throw new \phpbb\groupposition\exception('NO_GROUP');
}
return $row;
@@ -36,30 +38,30 @@ class phpbb_groupposition_teampage implements phpbb_groupposition_interface
* Constructor
*
- * @param phpbb_db_driver $db Database object
- * @param phpbb_user $user User object
- * @param phpbb_cache_driver_interface $cache Cache object
+ * @param \phpbb\db\driver\driver $db Database object
+ * @param \phpbb\user $user User object
+ * @param \phpbb\cache\driver\driver_interface $cache Cache object
*/